@@ -107,11 +107,14 @@ def es_condition_by_not_null(boo_must_list, column, param):
         })
 
 
-def es_condition_by_range(bool_must_list, column, date_list, is_contain_end_date=False):
+def es_condition_by_range(bool_must_list, column, date_list, is_contain_end_date=False, is_contain_start_date=True):
     if date_list:
         range_dict = {}
         if date_list[0]:
-            range_dict["gte"] = date_list[0]
+            if is_contain_start_date:
+                range_dict["gte"] = date_list[0]
+            else:
+                range_dict["gt"] = date_list[0]
         if len(date_list) == 2 and date_list[1]:
             end = date_list[1]
             if is_contain_end_date:
